/**
 * Copyright © 2010-2011 Olivier Cailloux
 *
 *     This file is part of JLP.
 *
 *     JLP is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Lesser General Public License version 3 as published by
 *     the Free Software Foundation.
 *
 *     JLP is distributed in the hope that it will be useful, but WITHOUT ANY
 * 	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * 	FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for
 * 	more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with JLP. If not, see <http://www.gnu.org/licenses/>.
 */
package org.decisiondeck.jlp.cplex;

import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class CplexLogger extends OutputStream {
    public enum OutLevel {
	DEBUG, INFO, WARNING, ERROR;
    }

    private static final Logger s_logger = LoggerFactory.getLogger(CplexLogger.class);

    private StringWriter m_str;

    private final OutLevel m_level;

    public CplexLogger(OutLevel outLevel) {
	m_level = outLevel;
	m_str = new StringWriter();
    }

    @Override
    public void write(int b) throws IOException {
	if (b == '\n') {
	    flush();
	} else {
	    m_str.write(b);
	}
    }

    @Override
    public void flush() throws IOException {
	if (m_str.toString().trim().length() != 0) {
	    final String toWrite;
	    // toWrite = m_str.toString().replaceAll("\\n", "");
	    toWrite = m_str.toString();
	    switch (m_level) {
	    case DEBUG:
		s_logger.debug(toWrite);
		break;
	    case INFO:
		s_logger.info(toWrite);
		break;
	    case WARNING:
		s_logger.warn(toWrite);
		break;
	    case ERROR:
		s_logger.error(toWrite);
		break;
	    default:
		throw new IllegalStateException("Unknown level.");
	    }
	}
	m_str = new StringWriter();
    }

}
